<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import MultiSelect from '@/Components/Chosen.vue';
import { ref, computed } from 'vue';
import { Head, useForm, usePage } from '@inertiajs/vue3';

const flashMessage = ref('');
const carBodyStyle = usePage().props.carBodyStyle;
const carMakes = computed(() => usePage().props.carMakes || []);
const carModels = computed(() => usePage().props.carModels || []);

// Transform carMakes data to the format { label: carMake.name, value: carMake.id }
const carMakeOptions = [];
carMakes.value.forEach(item => {
    carMakeOptions.push({
        label: item.name,
        value: item.id
    });
});

// Transform carModels data to the format { label: carModel.name, value: carModel.id }
const carModelOptions = [];
carModels.value.forEach(item => {
    carModelOptions.push({
        label: item.name,
        value: item.id
    });
});

const form = useForm({
    id: carBodyStyle.id,
    name: carBodyStyle.name,
    year: carBodyStyle.year,
    // year: Array.isArray(carBodyStyle.year) ? carBodyStyle.year : [carBodyStyle.year],
    make: carBodyStyle.make,
    model: carBodyStyle.model,
});

const selectedCarMakes = ref(
    carBodyStyle.make.split(',').map(Number)
);
const selectedCarModels = ref(
    carBodyStyle.model.split(',').map(Number)
);
const selectedCarYear = ref(
    carBodyStyle.year.split(',').map(Number)
);

// Update the form data with the selected car year
const updateSelectedCarYear = (selected) => {
  selectedCarYear.value = selected;
};

// Update the form data with the selected car makes
const updateSelectedCarMakes = (selected) => {
  selectedCarMakes.value = selected;
};

// Update the form data with the selected car model
const updateSelectedCarModels = (selected) => {
    selectedCarModels.value = selected;
};

const years = generateYears(1949, new Date().getFullYear());

function generateYears(start, end) {
  const years = [];
  for (let year = start; year <= end; year++) {
    years.push(year);
  }
  return years;
}

const reversedYears = computed(() => [...years].reverse());
const carYearOptions = [];
reversedYears.value.map(item => {
    const year = item;
    carYearOptions.push({
        label: year.toString().replace(',', ''),
        value: year
    });
});

const submit = () => {
    const carBodyStyleID = carBodyStyle.id;
    console.log(form.year);
    form.year = selectedCarYear.value.join(',');
    form.make = selectedCarMakes.value.join(',');
    form.model = selectedCarModels.value.join(',');
    form.post(route('admin.product.bodystyle.update',{id: carBodyStyleID}), {
        onSuccess: () => {
            flashMessage.value = "Car body style updated successfully!";
        },
        onError: (error) => {
            console.error(error);
        }
    });
};
</script>

<template>

    <Head title="Edit Body Style" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Edit Body Style <a :href="route('admin.products.allbodystyles')"  class="back-btn"> Back to list </a></h2>
        </template>

        <div class="py-12 container">

            <div v-if="flashMessage" class="mx-auto font-bold text-green-600">
                <div class="form-row">
                    <div class="col-12">
                        <h4 class="alert alert-success">{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <input type="hidden" id="id" v-model="form.id" />

            <div class="content-box sm:rounded-lg">
                <form @submit.prevent="submit">
                    <div class="form-row px-3">

                        <div class="mt-4 col-md-12">
                            <InputLabel for="name" value="Car Body Style" />

                            <TextInput
                                id="name"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.name"
                                required
                                autofocus
                                autocomplete="name"
                            />

                            <InputError class="mt-2" :message="form.errors.name" />
                        </div>

                        <div class="mt-4 col-lg-4 col-md-4 col-sm-12 col-12">
                            <InputLabel for="year" value="Year" />
                            <MultiSelect :options="carYearOptions" placeholder="Select Year" :selected="selectedCarYear" @update:selected="updateSelectedCarYear"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.year" />
                        </div>

                        <div class="mt-4 col-lg-4 col-md-4 col-sm-12 col-12">
                            <InputLabel for="name" value="Car Maker" />
                            <MultiSelect :options="carMakeOptions" placeholder="Select Make" :selected="selectedCarMakes" @update:selected="updateSelectedCarMakes"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.make" />
                        </div>

                        <div class="mt-4 col-lg-4 col-md-4 col-sm-12 col-12">
                            <InputLabel for="name" value="Car Model" />
                            <MultiSelect :options="carModelOptions" placeholder="Select Model" :selected="selectedCarModels" @update:selected="updateSelectedCarModels"></MultiSelect>
                            <InputError class="mt-2" :message="form.errors.model" />
                        </div>

                    </div>

                    <div class="flex items-center justify-start my-4 col-md-4 col-12">
                        <PrimaryButton class="btn btn-blue" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Update Body Style
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
